Package: GOpro
Type: Package
Title: Find the most characteristic gene ontology terms for groups of
        human genes
Version: 1.39.0
Author: Lidia Chrabaszcz
Maintainer: Lidia Chrabaszcz <chrabaszcz.lidia@gmail.com>
Description: Find the most characteristic gene ontology terms for
    groups of human genes.
    This package was created as a part of
    the thesis which was developed under the auspices of MI^2 Group
    (http://mi2.mini.pw.edu.pl/, https://github.com/geneticsMiNIng).
License: GPL-3
Depends: R (>= 3.5.0)
Imports: AnnotationDbi, dendextend, doParallel, foreach, parallel,
        org.Hs.eg.db, GO.db, Rcpp, stats, graphics,
        MultiAssayExperiment, IRanges, S4Vectors
LinkingTo: Rcpp, BH
RoxygenNote: 6.0.1
Suggests: knitr, rmarkdown, RTCGA.PANCAN12, BiocStyle, testthat
VignetteBuilder: knitr
LazyData: true
biocViews: Annotation, Clustering, GO, GeneExpression,
        GeneSetEnrichment, MultipleComparison
URL: https://github.com/mi2-warsaw/GOpro
BugReports: https://github.com/mi2-warsaw/GOpro/issues
git_url: https://git.bioconductor.org/packages/GOpro
git_branch: devel
git_last_commit: 91eede1
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: yes
Packaged: 2026-04-28 22:57:41 UTC; biocbuild
