# Generated by roxygen2: do not edit by hand

export(findGO)
import(AnnotationDbi)
import(GO.db)
import(dendextend)
import(doParallel)
import(foreach)
import(org.Hs.eg.db)
import(parallel)
importFrom(IRanges,CharacterList)
importFrom(IRanges,IntegerList)
importFrom(IRanges,NumericList)
importFrom(MultiAssayExperiment,assay)
importFrom(MultiAssayExperiment,experiments)
importFrom(Rcpp,sourceCpp)
importFrom(S4Vectors,DataFrame)
importFrom(S4Vectors,List)
importFrom(graphics,legend)
importFrom(graphics,plot)
importFrom(graphics,text)
importFrom(stats,TukeyHSD)
importFrom(stats,aggregate)
importFrom(stats,aov)
importFrom(stats,as.dendrogram)
importFrom(stats,dist)
importFrom(stats,hclust)
importFrom(stats,na.omit)
importFrom(stats,p.adjust)
useDynLib(GOpro)
useDynLib(GOpro, .registration=TRUE)
