# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

fisher_test <- function(a, b, c, d) {
    .Call('GOpro_fisher_test', PACKAGE = 'GOpro', a, b, c, d)
}

